@@ -46,6 +46,7 @@ from .gen.const import APP_GRAMPS, USER_DIRLIST, HOME_DIR
 from .gen.constfunc import mac
 from .version import VERSION_TUPLE
 from .gen.constfunc import win, get_env_var
+from .gen.config import config
 
 #-------------------------------------------------------------------------
 #
@@ -259,6 +260,8 @@ def show_settings():
         from gi import Repository
         repository = Repository.get_default()
         if repository.enumerate_versions("GExiv2"):
+            import gi
+            gi.require_version('GExiv2', '0.10')
             from gi.repository import GExiv2
             try:
                 gexiv2_str = GExiv2._version
@@ -447,6 +450,9 @@ def run():
         startcli(error, argpars)
 
 def main():
+    if win() and ('PANGOCAIRO_BACKEND' not in os.environ) and \
+            config.get('preferences.alternate-fonthandler'):
+        os.environ['PANGOCAIRO_BACKEND'] = "fontconfig"
     errors = run()
     if errors and isinstance(errors, list):
         for error in errors:
