@@ -79,6 +79,7 @@ for event_group, type_list in EventType().get_menu_standard_xml():
         TYPE2GROUP[event_type] = event_group
 SECTION_LIST.append(CUSTOM)
 TYPE2GROUP[EventType.CUSTOM] = CUSTOM
+TYPE2GROUP[EventType.UNKNOWN] = _T_("Unknown")
 
 #------------------------------------------------------------------------
 #
@@ -190,26 +191,8 @@ class IndivCompleteReport(Report):
             self.doc.end_superscript()
         self.doc.end_paragraph()
         
-        attr_list = event.get_attribute_list()
-        if len(attr_list):
-            for attr in attr_list:
-                attr_type = self._get_type(attr.get_type())
-                # translators: needed for French, ignore otherwise
-                text = self._("%(type)s: %(value)s") % {
-                                    'type'  : self._(attr_type),
-                                    'value' : attr.get_value() }
-                endnotes = self._cite_endnote(attr)
-                self.write_paragraph(text, endnotes)
-
-        attr_list = event_ref.get_attribute_list()
-        if len(attr_list):
-            for attr in attr_list:
-                # translators: needed for French, ignore otherwise
-                text = self._("%(type)s: %(value)s") % {
-                                    'type'  : self._(str(attr.get_type())),
-                                    'value' : attr.get_value() }
-                endnotes = self._cite_endnote(attr)
-                self.write_paragraph(text, endnotes)
+        self.do_attributes(event.get_attribute_list() +
+                           event_ref.get_attribute_list() )
 
         for notehandle in event.get_note_list():
             note = self._db.get_note_from_handle(notehandle)
@@ -413,7 +396,7 @@ class IndivCompleteReport(Report):
         self.doc.end_row()
         
         for attr in attr_list:
-            attr_type = self._get_type(attr.get_type())
+            attr_type = attr.get_type().type2base()
             self.doc.start_row()
             self.write_cell(self._(attr_type))
             text = attr.get_value()
@@ -490,7 +473,7 @@ class IndivCompleteReport(Report):
             tags.append(tag.get_name())
         for text in sorted(tags):
             self.doc.start_row()
-            self.write_cell(text)
+            self.write_cell(text, span=2)
             self.doc.end_row()
         self.doc.end_table()
         self.doc.start_paragraph('IDS-Normal')
@@ -547,6 +530,8 @@ class IndivCompleteReport(Report):
             self.write_paragraph(description, style='IDS-ImageCaptionCenter')
             ReportUtils.insert_image(self._db, self.doc, media_ref, self._user,
                                      align='center', w_cm=5.0, h_cm=5.0)
+            self.do_attributes(media.get_attribute_list() +
+                               media_ref.get_attribute_list() )
             self.doc.end_cell()
             if image_count % cells == cells - 1:
                 self.doc.end_row()
@@ -620,14 +605,7 @@ class IndivCompleteReport(Report):
                 self.doc.start_row()
                 self.write_cell(self._("Attributes"))
                 self.doc.start_cell("IDS-ListCell")
-                for attr in attr_list:
-                    attr_type = self._get_type(attr.get_type())
-                    # translators: needed for French, ignore otherwise
-                    text = self._("%(type)s: %(value)s") % {
-                                        'type'  : self._(attr_type),
-                                        'value' : attr.get_value() }
-                    endnotes = self._cite_endnote(attr)
-                    self.write_paragraph(text, endnotes)
+                self.do_attributes(attr_list)
                 self.doc.end_cell()
                 self.doc.end_row()
 
@@ -731,8 +709,9 @@ class IndivCompleteReport(Report):
             if group in event_dict:
                 self.write_section(event_dict[group], group)
 
-    def write_cell(self, text, endnotes=None, mark=None, style='IDS-Normal'):
-        self.doc.start_cell('IDS-NormalCell')
+    def write_cell(self, text,
+                   endnotes=None, mark=None, style='IDS-Normal', span=1):
+        self.doc.start_cell('IDS-NormalCell', span)
         self.write_paragraph(text, endnotes=endnotes, mark=mark, style=style)
         self.doc.end_cell()
 
@@ -859,7 +838,7 @@ class IndivCompleteReport(Report):
                 text = _('(image)')
             else:
                 for attr in attr_list:
-                    attr_type = self._get_type(attr.get_type())
+                    attr_type = attr.get_type().type2base()
                     # translators: needed for French, ignore otherwise
                     text = self._("%(str1)s: %(str2)s") % {
                                         'str1' : self._(attr_type),
@@ -923,6 +902,16 @@ class IndivCompleteReport(Report):
             txt = self._('%(str1)s, %(str2)s') % {'str1':prior, 'str2':txt}
         return txt
 
+    def do_attributes(self, attr_list):
+        for attr in attr_list:
+            attr_type = attr.get_type().type2base()
+            # translators: needed for French, ignore otherwise
+            text = self._("%(type)s: %(value)s") % {
+                                'type'  : self._(attr_type),
+                                'value' : attr.get_value() }
+            endnotes = self._cite_endnote(attr)
+            self.write_paragraph(text, endnotes)
+
 #------------------------------------------------------------------------
 #
 # IndivCompleteOptions
